pub enum BucketMapError {
DataNoSpace((u64, u8)),
IndexNoSpace(u64),
}👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Expand description
used to communicate resize necessary and current size.
Variants
DataNoSpace((u64, u8))
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.(bucket_index, current_capacity_pow2) Note that this is specific to data buckets, which grow in powers of 2
IndexNoSpace(u64)
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.current_capacity_entries Note that this is specific to index buckets, which can be ‘Actual’ sizes